Method: ISO3166::Country#postal_code_format

Defined in:
lib/countries/country.rb

#postal_code_formatString

Returns The regex for valid postal codes in this Country.

Returns:

  • (String)

    The regex for valid postal codes in this Country



91
92
93
# File 'lib/countries/country.rb', line 91

def postal_code_format
  "\\A#{data['postal_code_format']}\\Z" if postal_code
end